@@ -37,17 +37,17 @@ static int32_t socket_errno (void) {
 
 #ifdef _WIN32
 static void* socket_strerror_string_win (SPVM_ENV* env, SPVM_VALUE* stack, int32_t error_number, int32_t length) {
-  wchar_t *s = NULL;
-  FormatMessageW(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, 
-                 NULL, WSAGetLastError(),
-                 MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
-                 (LPWSTR)&s, 0, NULL);
+  char* error_message = NULL;
+  FormatMessageA(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, 
+                 NULL, error_number,
+                 MAKELANGID(LANG_ENGLISH, SUBLANG_ENGLISH_US),
+                 (LPSTR)&error_message, length, NULL);
   
-  void* error_message = env->new_string(env, stack, s, strlen(s));
+  void* obj_error_message = env->new_string(env, stack, error_message, strlen(error_message));
   
-  LocalFree(s);
+  LocalFree(error_message);
   
-  return error_message;
+  return obj_error_message;
 }
 #endif
 
@@ -61,6 +61,7 @@ static void* socket_strerror_string (SPVM_ENV* env, SPVM_VALUE* stack, int32_t e
   return obj_strerror_value;
 }
 
+
 static const char* socket_strerror(SPVM_ENV* env, SPVM_VALUE* stack, int32_t error_number, int32_t length) {
   void* obj_socket_strerror = socket_strerror_string(env, stack, error_number, length);
   
@@ -91,6 +92,206 @@ int32_t SPVM__Sys__Socket__socket_strerror(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
+int32_t SPVM__Sys__Socket__htonl(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t hostlong = stack[0].ival;
+  
+  int32_t netlong = htonl(hostlong);
+  
+  stack[0].ival = netlong;
+  
+  return 0;
+}
+
+int32_t SPVM__Sys__Socket__htons(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int16_t hostshort = stack[0].sval;
+  
+  int16_t netshort = htons(hostshort);
+  
+  stack[0].sval = netshort;
+  
+  return 0;
+}
+
+int32_t SPVM__Sys__Socket__ntohl(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t netlong = stack[0].ival;
+  
+  int32_t hostlong = ntohl(netlong);
+  
+  stack[0].ival = hostlong;
+  
+  return 0;
+}
+
+int32_t SPVM__Sys__Socket__ntohs(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int16_t netshort = stack[0].sval;
+  
+  int16_t hostshort = htons(netshort);
+  
+  stack[0].sval = hostshort;
+  
+  return 0;
+}
+
+int32_t SPVM__Sys__Socket__inet_aton(SPVM_ENV* env, SPVM_VALUE* stack) {
+
+  int32_t e = 0;
+  
+  int32_t InvalidNetworkAddress = env->get_class_id_by_name(env, stack, "Sys::Socket::Error::InetInvalidNetworkAddress", &e, FILE_NAME, __LINE__);
+  
+  void* obj_cp = stack[0].oval;
+  
+  if (!obj_cp) {
+    return env->die(env, stack, "The input address(cp) must be defined", FILE_NAME, __LINE__);
+  }
+  
+  const char* cp = env->get_chars(env, stack, obj_cp);
+  
+  void* obj_inp = stack[1].oval;
+  
+  if (!obj_inp) {
+    return env->die(env, stack, "The output address(inp) must be defined", FILE_NAME, __LINE__);
+  }
+  
+  struct in_addr* st_in_addr = env->get_pointer(env, stack, obj_inp);
+  
+#ifdef _WIN32
+  int32_t status = inet_pton(AF_INET, cp, st_in_addr);
+#else
+  int32_t status = inet_aton(cp, st_in_addr);
+#endif
+
+  if (status == 0) {
+    env->die(env, stack, "The address is not a valid network address", FILE_NAME, __LINE__);
+    return InvalidNetworkAddress;
+  }
+  else if (status == -1) {
+    env->die(env, stack, "[System Error]inet_aton failed: %s", socket_strerror(env, stack, socket_errno(), 0), FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
+  }
+  
+  stack[0].ival = status;
+  
+  return 0;
+}
+
+int32_t SPVM__Sys__Socket__inet_ntoa(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  void* obj_in = stack[0].oval;
+  
+  if (!obj_in) {
+    return env->die(env, stack, "The input address must be defined", FILE_NAME, __LINE__);
+  }
+  
+  struct in_addr* in = env->get_pointer(env, stack, obj_in);
+  
+  char* output_address = inet_ntoa(*in);
+
+  if (!output_address) {
+    env->die(env, stack, "[System Error]inet_ntoa failed: %s", socket_strerror(env, stack, socket_errno(), 0), FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
+  }
+  
+  void* obj_output_address;
+  if (output_address) {
+    obj_output_address = env->new_string(env, stack, output_address, strlen(output_address));
+  }
+  else {
+    assert(0);
+  }
+  
+  stack[0].oval = obj_output_address;
+  
+  return 0;
+}
+
+int32_t SPVM__Sys__Socket__inet_pton(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t e = 0;
+  
+  int32_t InvalidNetworkAddress = env->get_class_id_by_name(env, stack, "Sys::Socket::Error::InetInvalidNetworkAddress", &e, FILE_NAME, __LINE__);
+  
+  if (e) { return e; }
+  
+  int32_t af = stack[0].ival;
+  
+  if (!(af == AF_INET || af == AF_INET6)) {
+    return env->die(env, stack, "The address family must be AF_INET or AF_INET6", FILE_NAME, __LINE__);
+  }
+  
+  void* obj_src = stack[1].oval;
+  
+  if (!obj_src) {
+    return env->die(env, stack, "The input address(src) must be defined", FILE_NAME, __LINE__);
+  }
+  
+  const char* src = env->get_chars(env, stack, obj_src);
+  
+  void* obj_dst = stack[2].oval;
+  
+  if (!obj_dst) {
+    return env->die(env, stack, "The output address(dst) must be defined", FILE_NAME, __LINE__);
+  }
+  
+  void* dst = env->get_pointer(env, stack, obj_dst);
+  
+  int32_t status = inet_pton(af, src, dst);
+  
+  if (status == 0) {
+    env->die(env, stack, "The address is not a valid network address", FILE_NAME, __LINE__);
+    return InvalidNetworkAddress;
+  }
+  else if (status == -1) {
+    env->die(env, stack, "[System Error]inet_pton failed: %s", socket_strerror(env, stack, socket_errno(), 0), FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
+  }
+  
+  stack[0].ival = status;
+  
+  return 0;
+}
+
+int32_t SPVM__Sys__Socket__inet_ntop(SPVM_ENV* env, SPVM_VALUE* stack) {
+
+  // The address family
+  int32_t af = stack[0].ival;
+
+  if (!(af == AF_INET || af == AF_INET6)) {
+    return env->die(env, stack, "The address family must be AF_INET or AF_INET6", FILE_NAME, __LINE__);
+  }
+  
+  // The input address
+  void* obj_src = stack[1].oval;
+  if (!obj_src) {
+    return env->die(env, stack, "The input address(src) must be defined", FILE_NAME, __LINE__);
+  }
+  void* src = env->get_pointer(env, stack, obj_src);
+  
+  // The output address
+  void* obj_dst = stack[2].oval;
+  if (!obj_dst) {
+    return env->die(env, stack, "The output address(dst) must be defined", FILE_NAME, __LINE__);
+  }
+  char* dst = (char*)env->get_chars(env, stack, obj_dst);
+  
+  // The size of the output address
+  int32_t size = stack[3].ival;
+  
+  const char* dst_ret = inet_ntop(af, src, dst, size);
+  
+  if (!dst_ret) {
+    env->die(env, stack, "[System Error]inet_ntop failed: %s", socket_strerror(env, stack, socket_errno(), 0), FILE_NAME, __LINE__);
+    return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
+  }
+  
+  stack[0].oval = obj_dst;
+  
+  return 0;
+}
+
 int32_t SPVM__Sys__Socket__socket(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t domain = stack[0].ival;
@@ -498,171 +699,6 @@ int32_t SPVM__Sys__Socket__shutdown(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Sys__Socket__inet_aton(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef _WIN32
-  env->die(env, stack, "inet_aton is not supported on this system", FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
-#else
-  
-  void* obj_cp = stack[0].oval;
-  
-  if (!obj_cp) {
-    return env->die(env, stack, "The input address(cp) must be defined", FILE_NAME, __LINE__);
-  }
-  
-  const char* cp = env->get_chars(env, stack, obj_cp);
-  
-  void* obj_inp = stack[1].oval;
-  
-  if (!obj_inp) {
-    return env->die(env, stack, "The output address(inp) must be defined", FILE_NAME, __LINE__);
-  }
-  
-  struct in_addr* inp = env->get_pointer(env, stack, obj_inp);
-  
-  int32_t success = inet_aton(cp, inp);
-  
-  stack[0].ival = success;
-  
-  return 0;
-#endif
-}
-
-int32_t SPVM__Sys__Socket__inet_ntoa(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  void* obj_in = stack[0].oval;
-  
-  if (!obj_in) {
-    return env->die(env, stack, "The input address must be defined", FILE_NAME, __LINE__);
-  }
-  
-  struct in_addr* in = env->get_pointer(env, stack, obj_in);
-  
-  char* output_address = inet_ntoa(*in);
-  
-  void* obj_output_address;
-  if (output_address) {
-    obj_output_address = env->new_string(env, stack, output_address, strlen(output_address));
-  }
-  else {
-    assert(0);
-  }
-  
-  stack[0].oval = obj_output_address;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__Socket__inet_pton(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t af = stack[0].ival;
-  
-  void* obj_src = stack[1].oval;
-  
-  if (!obj_src) {
-    return env->die(env, stack, "The input address(src) must be defined", FILE_NAME, __LINE__);
-  }
-  
-  const char* src = env->get_chars(env, stack, obj_src);
-  
-  void* obj_dst = stack[2].oval;
-  
-  if (!obj_dst) {
-    return env->die(env, stack, "The output address(dst) must be defined", FILE_NAME, __LINE__);
-  }
-  
-  void* dst = env->get_pointer(env, stack, obj_dst);
-  
-  int32_t success = inet_pton(af, src, dst);
-  
-  if (success == -1) {
-    env->die(env, stack, "[System Error]inet_pton failed: %s", socket_strerror(env, stack, socket_errno(), 0), FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
-  }
-  
-  stack[0].ival = success;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__Socket__inet_ntop(SPVM_ENV* env, SPVM_VALUE* stack) {
-
-  // The address family
-  int32_t af = stack[0].ival;
-  
-  // The input address
-  void* obj_src = stack[1].oval;
-  if (!obj_src) {
-    return env->die(env, stack, "The input address(src) must be defined", FILE_NAME, __LINE__);
-  }
-  void* src = env->get_pointer(env, stack, obj_src);
-  
-  // The output address
-  void* obj_dst = stack[2].oval;
-  if (!obj_dst) {
-    return env->die(env, stack, "The output address(dst) must be defined", FILE_NAME, __LINE__);
-  }
-  char* dst = (char*)env->get_chars(env, stack, obj_dst);
-  
-  // The size of the output address
-  int32_t size = stack[3].ival;
-  
-  const char* dst_ret = inet_ntop(af, src, dst, size);
-  
-  if (!dst_ret) {
-    env->die(env, stack, "[System Error]inet_ntop failed: %s", socket_strerror(env, stack, socket_errno(), 0), FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
-  }
-  
-  stack[0].oval = obj_dst;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__Socket__htonl(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t hostlong = stack[0].ival;
-  
-  int32_t netlong = htonl(hostlong);
-  
-  stack[0].ival = netlong;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__Socket__htons(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int16_t hostshort = stack[0].sval;
-  
-  int16_t netshort = htons(hostshort);
-  
-  stack[0].sval = netshort;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__Socket__ntohl(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t netlong = stack[0].ival;
-  
-  int32_t hostlong = ntohl(netlong);
-  
-  stack[0].ival = hostlong;
-  
-  return 0;
-}
-
-int32_t SPVM__Sys__Socket__ntohs(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int16_t netshort = stack[0].sval;
-  
-  int16_t hostshort = htons(netshort);
-  
-  stack[0].sval = hostshort;
-  
-  return 0;
-}
-
 int32_t SPVM__Sys__Socket__ioctlsocket(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 #ifndef _WIN32
