@@ -36,33 +36,39 @@ The destructor.
 
 =head2 sa_family
 
-  method sa_family : int ()
+  method sa_family : byte ()
 
-Get C<sa_family>. This is the overriden method of the L<sa_family|SPVM::Sys::Socket::Sockaddr/"sa_family"> method in the Sys::Socket::Sockaddr class.
+Gets C<sa_family>. This is the overriden method of the L<sa_family|SPVM::Sys::Socket::Sockaddr/"sa_family"> method in the Sys::Socket::Sockaddr class.
 
 =head2 sun_family
 
-  method sun_family : int ();
+  method sun_family : byte ();
 
-Get C<sun_family>.
+Gets C<sun_family>.
 
 =head2 set_sun_family
 
-  method set_sun_family : int ();
+  method set_sun_family : void ($family : byte)
 
-Set C<sun_family>.
+Sets C<sun_family>.
 
 =head2 sun_path
 
   method sun_path : string ();
 
-Get C<sun_path>.
+Gets C<sun_path>.
 
 =head2 set_sun_path
 
-  method set_sun_path : void ($path : string);
+  method set_sun_path : void ($path : string)
 
-Set C<sun_path>.
+Sets C<sun_path>.
+
+=head2 sizeof
+
+  method sizeof : int ()
+
+The size of C<struct sockaddr_un>.
 
 =head1 Copyright & License
 
